//-------------------------------------------
// This file is part of the PhotonLoop project
// Do not distribute without explicit consent
//
// Copyright (C) 2021 Jacopo Mocci
// Informatic Engineer at DYNAMIC OPTICS s.r.l.
// Piazza Giacomo Zanellato, 5 torre 1
// 35131 Padova (PD) - Italia
//
// mailto::jacopo.mocci@dynamic-optics.it
//-------------------------------------------

#ifndef ACTUATORSDRIVERPLUGIN_H
#define ACTUATORSDRIVERPLUGIN_H

#include "plugin.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct ADPluginSettings
{
    double voltage_center;
    double voltage_upper;
    double voltage_lower;
    int actuators;
} ADPluginSettings;

// Open driver
PLUGINSDLL_API int pd_open();

// Close driver
PLUGINSDLL_API int pd_close();


// Set plugin settings
PLUGINSDLL_API int pd_setSettings(ADPluginSettings ad_settings);

// Set actuators zero
PLUGINSDLL_API int pd_setZero();

// Set actuators value
PLUGINSDLL_API int pd_setValue(double value, int actuator);

// Set actuators values
PLUGINSDLL_API int pd_setValues(double *values, int size);


// Get plugin info
PLUGINSDLL_API int pd_getInfo(PluginInfo *pluginInfo);

// Get last error
PLUGINSDLL_API int pd_lastError(char *errstr);

// Get plugin settings
PLUGINSDLL_API int pd_getSettings(ADPluginSettings *ad_settings);


// UNUSED
PLUGINSDLL_API int pd_showGui();

// UNUSED
PLUGINSDLL_API int pd_setInstance(int index);

// Properties
PLUGINSDLL_API int pd_setProperties(const char *);
PLUGINSDLL_API int pd_getProperties(char *);


#ifdef __cplusplus
}
#endif

#endif // ACTUATORSDRIVERPLUGIN_H
