#include "actuatorsdriverplugin.h"
#include <iostream>
#include <chrono>
#include <thread>

int main()
{
    std::cout << "Actuators Driver Plugin Example" << std::endl << std::endl;

    ADPluginSettings settings;
    PluginInfo info;
    char* errstr = const_cast<char*>("");

    settings.voltage_center =  0.1;
    settings.voltage_upper  =  0.9;
    settings.voltage_lower  = -0.6;
    settings.actuators      =  18;

    int ret;

    ret = pd_setSettings(settings);
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    ret = pd_open();
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    ret = getPluginInfo(&info);
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    std::cout << "Plugin info: " << std::endl;
    std::cout << "Interface Version:           " << info.interfaceVersion << std::endl;
    std::cout << "Filename:                    " << info.filename << std::endl;
    std::cout << "Name:                        " << info.name << std::endl;
    std::cout << "Version:                     " << info.version << std::endl;
    std::cout << "Path:                        " << info.path << std::endl;
    std::cout << "Plugin Type:                 " << info.pluginType << std::endl << std::endl;

    pd_getSettings(&settings);
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    std::cout << "Settings: " << std::endl;
    std::cout << "Voltage center: " << settings.voltage_center << std::endl;
    std::cout << "Voltage upper:  " << settings.voltage_upper << std::endl;
    std::cout << "Voltage lower:  " << settings.voltage_lower << std::endl;
    std::cout << "Actuators:      " << settings.actuators << std::endl << std::endl;

    ret = pd_setZero();
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    std::cout << "Zero set" << std::endl;
    std::cout << "Setting actuator 1 to 0.5" << std::endl;
    std::cout << "Press enter to continue..." << std::endl << std::endl;

    std::cin.get();

    double* values = new double[settings.actuators];
    for (int i = 0; i < settings.actuators; i++)
    {
        values[i] = 0.0;
    }

    values[0] = 0.5;
    pd_setValues(values, 18);
    if (ret != 0)
    {
        pd_lastError(errstr);
        printf("Error: %s\n", errstr);
        return 1;
    }

    pd_setValue(0.9,1);

    std::cout << "Actuator 0 and 1 set" << std::endl;
    std::cout << "Press enter to close..." << std::endl;

    std::cin.get();

    pd_close();
    
}