//-------------------------------------------
// This file is part of the PhotonLoop project
// Do not distribute without explicit consent
//
// Copyright (C) 2016 Jacopo Mocci
// Ph.D. student at University of Verona,
// Department of Computer Science
// Strada Le Grazie 15, 37134 Verona, Italy
//
// mailto::jacopo.mocci@univr.it
//-------------------------------------------
#ifndef PLUGIN_H
#define PLUGIN_H

#define PLUGIN_INTERFACE_VERSION "1.0"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef NOMINMAX
# define NOMINMAX
#endif

#ifdef _WIN32
#include <windows.h>

#ifdef PLUGINSDLL_EXPORTS
#define PLUGINSDLL_API __declspec(dllexport)
#else
#define PLUGINSDLL_API __declspec(dllimport)
#endif

#else
#define PLUGINSDLL_API
#endif

#define STRLEN 1024
#define JSONLEN 1024*128

typedef enum PluginType
{
    COMPENSATORPLUGIN,
    SENSORPLUGIN,
    ACTUATORPLUGIN
} PluginType;

typedef enum PluginErrorCodes
{
    E_SUCCESS = 0,
    E_GENERIC_ERROR = 1,
    E_INVALID = 2,
    E_ALREADY_OPENED = 3,
    E_NOT_OPENED = 4,
    E_INVALID_ACTUATOR_NUMBER = 5,
    E_DEVICE_ERROR = 6,
    E_NOT_FOUND = 7
} PluginErrorCodes;

typedef struct PluginInfo
{
//    PluginInfo()
//    {
//        strcpy_s(interfaceVersion, PLUGIN_INTERFACE_VERSION);
//        memset(filename, 0, sizeof(filename));
//        memset(name, 0, sizeof(name));
//        memset(version, 0, sizeof(version));
//        memset(path, 0, sizeof(path));
//    }

    char interfaceVersion[STRLEN];

    char filename[STRLEN];
    char name[STRLEN];
    char version[STRLEN];
    char path[STRLEN];

    PluginType pluginType;
} PluginInfo;

PLUGINSDLL_API int getPluginInfo(PluginInfo *);

#ifdef __cplusplus
}
#endif

#endif // PLUGIN_H
